@@ -1,5 +1,5 @@
 #  Pyrogram - Telegram MTProto API Client Library for Python
-#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
+#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
 #
 #  This file is part of Pyrogram.
 #
@@ -16,19 +16,20 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
+import os
 import re
 
+import pyrogram
 from pyrogram import raw
 from pyrogram import types
 from pyrogram import utils
-from pyrogram.scaffold import Scaffold
-from .inline_session import get_session
 from pyrogram.file_id import FileType
+from .inline_session import get_session
 
 
-class EditInlineMedia(Scaffold):
+class EditInlineMedia:
     async def edit_inline_media(
-        self,
+        self: "pyrogram.Client",
         inline_message_id: str,
         media: "types.InputMedia",
         reply_markup: "types.InlineKeyboardMarkup" = None
@@ -60,47 +61,113 @@ class EditInlineMedia(Scaffold):
                 # Bots only
 
                 # Replace the current media with a local photo
-                app.edit_inline_media(inline_message_id, InputMediaPhoto("new_photo.jpg"))
+                await app.edit_inline_media(inline_message_id, InputMediaPhoto("new_photo.jpg"))
 
                 # Replace the current media with a local video
-                app.edit_inline_media(inline_message_id, InputMediaVideo("new_video.mp4"))
+                await app.edit_inline_media(inline_message_id, InputMediaVideo("new_video.mp4"))
 
                 # Replace the current media with a local audio
-                app.edit_inline_media(inline_message_id, InputMediaAudio("new_audio.mp3"))
+                await app.edit_inline_media(inline_message_id, InputMediaAudio("new_audio.mp3"))
         """
         caption = media.caption
         parse_mode = media.parse_mode
 
         if isinstance(media, types.InputMediaPhoto):
-            if re.match("^https?://", media.media):
+            if os.path.isfile(media.media):
+                media = raw.types.InputMediaUploadedPhoto(
+                    file=await self.save_file(media.media)
+                )
+            elif re.match("^https?://", media.media):
                 media = raw.types.InputMediaPhotoExternal(
                     url=media.media
                 )
             else:
                 media = utils.get_input_media_from_file_id(media.media, FileType.PHOTO)
         elif isinstance(media, types.InputMediaVideo):
-            if re.match("^https?://", media.media):
+            if os.path.isfile(media.media):
+                media = raw.types.InputMediaUploadedDocument(
+                    mime_type=self.guess_mime_type(media.media) or "video/mp4",
+                    thumb=await self.save_file(media.thumb),
+                    file=await self.save_file(media.media),
+                    attributes=[
+                        raw.types.DocumentAttributeVideo(
+                            supports_streaming=media.supports_streaming or None,
+                            duration=media.duration,
+                            w=media.width,
+                            h=media.height
+                        ),
+                        raw.types.DocumentAttributeFilename(
+                            file_name=os.path.basename(media.media)
+                        )
+                    ]
+                )
+            elif re.match("^https?://", media.media):
                 media = raw.types.InputMediaDocumentExternal(
                     url=media.media
                 )
             else:
                 media = utils.get_input_media_from_file_id(media.media, FileType.VIDEO)
         elif isinstance(media, types.InputMediaAudio):
-            if re.match("^https?://", media.media):
+            if os.path.isfile(media.media):
+                media = raw.types.InputMediaUploadedDocument(
+                    mime_type=self.guess_mime_type(media.media) or "audio/mpeg",
+                    thumb=await self.save_file(media.thumb),
+                    file=await self.save_file(media.media),
+                    attributes=[
+                        raw.types.DocumentAttributeAudio(
+                            duration=media.duration,
+                            performer=media.performer,
+                            title=media.title
+                        ),
+                        raw.types.DocumentAttributeFilename(
+                            file_name=os.path.basename(media.media)
+                        )
+                    ]
+                )
+            elif re.match("^https?://", media.media):
                 media = raw.types.InputMediaDocumentExternal(
                     url=media.media
                 )
             else:
                 media = utils.get_input_media_from_file_id(media.media, FileType.AUDIO)
         elif isinstance(media, types.InputMediaAnimation):
-            if re.match("^https?://", media.media):
+            if os.path.isfile(media.media):
+                media = raw.types.InputMediaUploadedDocument(
+                    mime_type=self.guess_mime_type(media.media) or "video/mp4",
+                    thumb=await self.save_file(media.thumb),
+                    file=await self.save_file(media.media),
+                    attributes=[
+                        raw.types.DocumentAttributeVideo(
+                            supports_streaming=True,
+                            duration=media.duration,
+                            w=media.width,
+                            h=media.height
+                        ),
+                        raw.types.DocumentAttributeFilename(
+                            file_name=os.path.basename(media.media)
+                        ),
+                        raw.types.DocumentAttributeAnimated()
+                    ]
+                )
+            elif re.match("^https?://", media.media):
                 media = raw.types.InputMediaDocumentExternal(
                     url=media.media
                 )
             else:
                 media = utils.get_input_media_from_file_id(media.media, FileType.ANIMATION)
         elif isinstance(media, types.InputMediaDocument):
-            if re.match("^https?://", media.media):
+            if os.path.isfile(media.media):
+                media = raw.types.InputMediaUploadedDocument(
+                    mime_type=self.guess_mime_type(media.media) or "application/zip",
+                    thumb=await self.save_file(media.thumb),
+                    file=await self.save_file(media.media),
+                    attributes=[
+                        raw.types.DocumentAttributeFilename(
+                            file_name=os.path.basename(media.media)
+                        )
+                    ]
+                )
+            elif re.match("^https?://", media.media):
                 media = raw.types.InputMediaDocumentExternal(
                     url=media.media
                 )
@@ -112,11 +179,11 @@ class EditInlineMedia(Scaffold):
 
         session = await get_session(self, dc_id)
 
-        return await session.send(
+        return await session.invoke(
             raw.functions.messages.EditInlineBotMessage(
                 id=unpacked,
                 media=media,
-                reply_markup=reply_markup.write() if reply_markup else None,
+                reply_markup=await reply_markup.write(self) if reply_markup else None,
                 **await self.parser.parse(caption, parse_mode)
             ),
             sleep_threshold=self.sleep_threshold
